// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
funcprot(0);
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

t2s=24*60*60;

function [x,y]=fOrt(t,param)
    sc=1.0E+9;
    // t in Tage
    t=t*t2s;
    R=param.r;
    Omega=param.omega;
    Phi0=param.phi0;
    
    x=(R/sc)*cos(Omega*t+Phi0);
    y=(R/sc)*sin(Omega*t+Phi0);
endfunction

function omega=fOmega(T) // Tage
    omega=(2*%pi)/(T*t2s);
endfunction

function phi0=fPhi0(x0,y0)
    phi0=atan(y0/x0);
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

function plotBody(posx,posy,col)
  plot(posx,posy);  
  h = CL_g_select(gce(), "Polyline");
  h.line_mode = "off"; 
  h.mark_mode = "on"; 
  h.mark_style = 0; // round mark
  h.mark_background = col;
  h.mark_foreground = col;
  h.mark_size_unit = "point"; 
  h.mark_size = 5;
endfunction

function [pos] = getBodyPos(name, cjd)
  cen="Sun";
  frame="EOD";
  pos_ICRS = CL_eph_de405(name, cjd, cen);
  pos = CL_fr_convert("ICRS", frame, cjd, pos_ICRS);
endfunction

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// Erde
paramE=[];
Re=149.67*1.0E+9; // [m]
Te=365.26; // [Tage]
X0e=25.338841*1.0E+9; // [m]
Y0e=-149.965279*1.0E+9; // [m]

paramE=[];
paramE.r=Re;
paramE.omega=fOmega(Te);
paramE.phi0=fPhi0(X0e,Y0e);

// Mars
Rm=227.7*1.0E+9; // [m]
Tm=686.98; // [Tage]
X0m=-115.281615*1.0E+9; // [m]     
Y0m=-197.167462*1.0E+9; // [m]

paramM=[];
paramM.r=Rm;
paramM.omega=fOmega(Tm);
paramM.phi0=fPhi0(X0m,Y0m);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

scal="2014/04/01 12:00:00.000"; // <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

Start=-80;
Ende=80;
Tnull=0-Start+1
Anzahl=Ende-Start+1;
tData = linspace(Start,Ende,Anzahl);

cal_ref = CL_dat_str2cal(scal);
datestr = tokens(CL_dat_cal2str(cal_ref)); 

t0=CL_dat_cal2cjd(CL_dat_str2cal(scal));
posE=getBodyPos("Earth",t0);
posM=getBodyPos("Mars",t0);

paramE.phi0=fPhi0(posE(1),posE(2));
paramM.phi0=fPhi0(posM(1),posM(2));

[xe,ye]=fOrt(tData,paramE);
[xm,ym]=fOrt(tData,paramM);

xem=xm-xe;
yem=ym-ye;

rem=sqrt(xem^2+yem^2);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

zem=zeros(xem);

pos_sph=CL_co_car2sph([xem;yem;zem]);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle1=scf(1);
clf(my_handle1,"reset");
a=gca();
a.isoview='on';

drawlater();

for Ix=1:10:Anzahl
    if Ix==1 then
        xset("color",color("gold"));
    else
        xset("color",color("gainsboro"));
    end
    
    xv(1)=0;
    xv(2)=xem(Ix);
    yv(1)=0;
    yv(2)=yem(Ix);
    xpoly(xv,yv);
end

xset("color",1);

plot2d(xem,yem,color("magenta"));
a.children;
poly1= a.children.children(1);
poly1.thickness = 2; 

plotBody(0,0,color("steelblue3"));
plotBody(xem(1),yem(1),color("magenta"));
plotBody(xem(Tnull),yem(Tnull),color("magenta"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " x (10^6 km) ", ..
        " y (10^6 km) " );

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle2=scf(2);
clf(my_handle2,"reset");
a=gca();
a.isoview='on';

drawlater();

plot2d(tData,rem,color("steelblue3"));

plotBody(Start,rem(1), color("steelblue3"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ",..
          Tage: " + string(Start) + " .. " + string(Ende),..
        " Tag ", ..
        " Abstand Erde - Mars (10^6 km) " );

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

delta2=[];

r2d=(180/%pi);
r2dm=r2d*60;

for Ix=1:1:Anzahl
    delta2(Ix)=yem(Ix)/rem(Ix);
    delta2(Ix)=r2d*acos(delta2(Ix));
end

my_handle4=scf(4);
clf(my_handle4,"reset");
a=gca();
a.isoview='off';

drawlater();

plot2d(tData,delta2,color("steelblue3"));

plotBody(Start,delta2(1), color("steelblue3"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " Tag ", ..
        " Winkel gegen y [Grad] " );

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

delta=[];

r2dm=(180/%pi)*60;

for Ix=1:1:Anzahl-1
    delta(Ix)=(xem(Ix)*xem(Ix+1)+yem(Ix)*yem(Ix+1))/(rem(Ix)*rem(Ix+1));
    delta(Ix)=r2dm*acos(delta(Ix));
end

my_handle3=scf(3);
clf(my_handle3,"reset");
a=gca();
a.isoview='off';

drawlater();

tDatam1=tData(1:(Anzahl-1))

plot2d(tDatam1,delta,color("steelblue3"));

plotBody(Start,delta(1), color("steelblue3"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " Tag ", ..
        " Delta-Winkel [Minuten] " );

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

delta3=[];

r2dm=(180/%pi)*60;

for Ix=1:1:Anzahl-1
    delta3(Ix)=(xem(Ix)*xem(Ix+1)+yem(Ix)*yem(Ix+1))/(rem(Ix)*rem(Ix+1));
    delta3(Ix)=r2dm*acos(delta3(Ix));
    
    if delta2(Ix) < delta2(Ix+1) then
        delta3(Ix)=-delta3(Ix);
    end
end

my_handle4=scf(4);
clf(my_handle4,"reset");
a=gca();
a.isoview='off';

drawlater();

tDatam1=tData(1:(Anzahl-1))

plot2d(tDatam1,delta3,color("steelblue3"));

plotBody(Start,delta3(1), color("steelblue3"));

xpoly([Start,Ende],[0,0]);
p=get("hdl");
p.foreground=color("gray70");

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " Tag ", ..
        " Gerichteter Delta-Winkel [Minuten] " );

drawnow();

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle5=scf(5);
clf(my_handle5,"reset");
a=gca();
a.isoview='off';

phiv=pos_sph(1,:)*r2d;

drawlater();

plot2d(tData,phiv,color("steelblue3"));

plotBody(Start,phiv(1), color("steelblue3"));

a.labels_font_size=3;
a.x_label.font_size = 3;
a.y_label.font_size = 3;
a.title.font_size = 3;

xtitle (" Mars- und Erdumlauf  -  " + datestr(1) + ", Tage: " + string(Start) + " .. " + string(Ende),..
        " Tag ", ..
        " Sphärischer Winkel [Grad] " );

drawnow();






