// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
funcprot(0);
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// Get body position from 'cent' in EOD
// cjd: TREF time scale

function [pos_ECI]=getBodyPos(name,cjd)
  cent="Earth";
  pos_ICRS=CL_eph_de405(name,cjd,cent);

  pos_ECI=CL_fr_convert("ICRS","ECI",cjd,pos_ICRS);
endfunction

// #####################################################################
// Main

r2d=(180/%pi);

// longitude/latitude/altitude of location

lon=11.42*%CL_deg2rad;
lat=48.15*%CL_deg2rad;
alt=531;

// scal=reference date (string, calendar)
scal=[];

scal="2014/04/01 12:00:00.000";

loc=[lon;lat;alt];

t0=CL_dat_cal2cjd(CL_dat_str2cal(scal));

dur = [60,60]; // days before/after

tsteps = 1; // steps (trajectory) - days
//           ^^ Not used

cjd_ref = t0;
cjd_start = cjd_ref - dur(1);
cjd_end = cjd_ref + dur(2);

traj_step = tsteps;

// dates for trajectory
cjd_traj = cjd_ref;
if (traj_step > 0)
  cjd_traj = cjd_start : traj_step : cjd_end;
end

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

nbTimes=size(cjd_traj,"c");

azimv=[];
elevv=[];

for Ix=1:nbTimes
    pos_ECI=getBodyPos("Mars",cjd_traj(Ix))
    pos_sph=CL_co_car2sph(pos_ECI);
    azimv(Ix)=pos_sph(1);
    elevv(Ix)=pos_sph(2);
end

xv=cos(azimv) .* cos(elevv);
yv=sin(azimv) .* cos(elevv);
zv=sin(elevv);

azimvd=azimv*r2d;
elevvd=elevv*r2d;

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle60=scf(60);
clf(my_handle60,"reset");
a=gca();
a.isoview='off';

nbazims=size(azimv,"r");
wdata=linspace(1,nbazims,nbazims);

subplot(211)
plot2d(wdata,azimvd,color("steelblue3"));
subplot(212)
plot2d(wdata,elevvd,color("steelblue3"));

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle62=scf(62);
clf(my_handle62,"reset");
a=gca();

subplot(2,1,1);
param3d(xv,yv,zv);
subplot(2,1,2);
param3d(xv,yv,zv,flag=[5,4],ebox=[-1,1,-1,1,-1,1]);

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

my_handle63=scf(63);
clf(my_handle63,"reset");
a=gca();

plot2d(xv,yv);




